@@ -45,7 +45,8 @@ metals = ["Li", "Be", "Na", "Mg", "Al", "K", "Ca", "Sc", "Ti", "V",
 atom_num_lab = dict(zip(atom_lab_num.values(), atom_lab_num.keys()))
 
 
-def load_xyz(f_name: str, atomic_numbers: bool = False):
+def load_xyz(f_name: str, atomic_numbers: bool = False,
+             add_indices bool = False):
     """
     Load labels and coordinates from a .xyz file
 
@@ -53,9 +54,12 @@ def load_xyz(f_name: str, atomic_numbers: bool = False):
     ----------
     f_name : str
         File name
-    atomic_numbers : bool, optional
+    atomic_numbers : bool, default False
         If true, will read xyz file with atomic numbers and convert
         to labels
+    add_indices : bool, default False
+        If true, add indices to atomic labels
+        (replacing those which may exist already)
 
     Returns
     -------
@@ -74,6 +78,10 @@ def load_xyz(f_name: str, atomic_numbers: bool = False):
     # Set labels as capitals
     _labels = [lab.capitalize() for lab in _labels]
 
+    if add_indices:
+        _labels = remove_numbers(_labels)
+        _labels = add_numbers(_labels)
+
     _coords = np.loadtxt(f_name, skiprows=2, usecols=(1, 2, 3))
 
     return _labels, _coords
@@ -93,14 +101,14 @@ def save_xyz(f_name: str, labels: list, coords: list,
         atomic labels
     coords : list
         list of 3 element lists containing xyz coordinates of each atom
-    with_numbers : bool, optional
+    with_numbers : bool, default False
         If True, add/overwrite numbers to labels before printing
-    verbose : bool, optional
+    verbose : bool, default True
         Print information on filename to screen
     mask : list, optional
         n_atom list of 0 (exclude) and 1 (include) indicating which
         atoms to print
-    atomic_numbers : bool, optional
+    atomic_numbers : bool, default False
         If true, will save xyz file with atomic numbers
 
     Returns
@@ -352,7 +360,7 @@ def formdict_to_formstr(form_dict: dict, include_one: bool = False):
     ----------
     form_dict : dict
         dictionary of {atomic label:quantity} pairs
-    include_one : bool, optional
+    include_one : bool, default False
         Include 1 in final chemical formula e.g. C1H4
 
     Returns
@@ -506,6 +514,11 @@ def get_adjacency(labels: list, coords: list, adjust_cutoff: dict = {},
         list of lists of xyz coordinates of each atom
     adjust_cutoff : dict, optional
         dictionary of atoms (keys) and new cutoffs (values)
+    save : bool, default False
+        If true save to file given by `f_name`
+    f_name : str, default 'adjacency.dat'
+        If save true, this name is used for the file containing the adjacency
+        matrix
 
     Returns
     -------
@@ -547,14 +560,13 @@ def get_bonds(labels: list, coords: list, neigh_list=None,
         list of lists of xyz coordinates of each atom
     neigh_list : ASE neighbourlist object, optional
         neighbourlist of system
-    f_name : str, optional
+    f_name : str, 'bonds.dat'
         filename to save bond list to
-    save : bool, optional
+    save : bool, default False
         Save bond list to file
-    verbose : bool, optional
+    verbose : bool, default True
         Print number of bonds to screen
-    style : str, optional
-        {'indices','labels'}
+    style : str, {'indices','labels'}
             indices : Bond list contains atom number
             labels  : Bond list contains atom label
 
@@ -635,14 +647,13 @@ def get_angles(labels: list, coords: list, neigh_list=None,
         list of lists of xyz coordinates of each atom
     neigh_list : ASE neighbourlist object, optional
         neighbourlist of system
-    f_name : str, optional
+    f_name : str, default 'angles.dat'
         filename to save angle list to
-    save : bool, optional
+    save : bool, default False
         Save angle list to file
-    verbose : bool, optional
+    verbose : bool, default True
         Print number of angles to screen
-    style : str, optional
-        {'indices','labels'}
+    style : str, {'indices','labels'}
             indices : Angle list contains atom number
             labels  : Angle list contains atom label
 
@@ -724,14 +735,13 @@ def get_dihedrals(labels: list, coords: list, neigh_list=None,
         list of lists of xyz coordinates of each atom
     neigh_list : ASE neighbourlist object, optional
         neighbourlist of system
-    f_name : str, optional
+    f_name : str, default 'dihedrals.dat'
         filename to save angle list to
-    save : bool, optional
+    save : bool, default False
         Save angle list to file
-    verbose : bool, optional
+    verbose : bool, default True
         Print number of dihedrals to screen
-    style : str, optional
-        {'indices','labels'}
+    style : str, {'indices','labels'}
             indices : Dihedral list contains atom number
             labels  : Dihedral list contains atom label
 
